Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Localisation ¶
type PointRetrait ¶
type PointRetrait struct {
Nom string `bson:"nom"`
Localisation *Localisation `bson:"localisation"`
}
type Produit ¶
type Produit struct {
ID primitive.ObjectID `bson:"_id,omitempty"`
Ref string `bson:"ref"`
Description string `bson:"description"`
Prix float32 `bson:"prix"`
Photos []*Photo `bson:"photos"`
Stocks []*Stock `bson:"stocks"`
Tags []string `bson:"tags"`
}
func FromProduitPB ¶
FromProduitPB parses a produit defined by the protobuff into a mongo produit document
func (*Produit) ToProduitPB ¶
ToProduitPB parses a mongo produit document into a produit defined by the protobuff
type Stock ¶
type Stock struct {
PointRetrait *PointRetrait `bson:"pointRetrait"`
Qte int32 `bson:"qte"`
}
Click to show internal directories.
Click to hide internal directories.